Module jwk

Module jwk 

Contains helpers for serializing and deserializing

This module contains helpers for serializing and deserializing JSON Web Keys (JWK) and JSON Web Key Sets (JWKS). It provides functions to convert cryptographic keys to the JWK format and handle the serialization for use in applications that require JWKs.

Key functionalities:

  • Convert RSA and ECDSA (ES256) keys to JWK format.
  • Serialize and deserialize JWKS (JSON Web Key Sets).

Structs

Jwk
Representing a JSON Web Key (JWK)
JwkBuilder
A builder for constructing a JSON Web Key (JWK).
Jwks
Represents a JSON Web Key Set (JWKS).

Functions

create_jwks
Creates a JSON Web Key Set (JWKS) from a collection of individual JWKs.